<?php
/*
Template Name: Contact / Appointment Page
*/
?>

<?php
	// Sanitize data, or initialize if they don't exist.
	$clientname = isset($_POST['the_name']) ? esc_html(trim($_POST['the_name'])) : '';
	$email = isset($_POST['the_email']) ? esc_html(trim($_POST['the_email'])) : '';
	$app_date = isset($_POST['app_date']) ? esc_html(trim($_POST['app_date'])) : '';
	$message = isset($_POST['the_message']) ? sanitize_text_field(stripslashes($_POST['the_message'])) : '';
	if(!empty($_POST['service_select']))
		$service_id = intval($_POST['service_select']);
	elseif(!empty($_GET['service_select']))
		$service_id = intval($_GET['service_select']);
	else
		$service_id = '';
	
	$errorString = '';
	$emailSent = false;
	
	if(isset($_POST['send_appointment']))
	{
		// We are here because the form was submitted. Let's validate!

		if(empty($clientname) or mb_strlen($clientname) < 2)
			$errorString .= '<li>'.__('Your name is required.', 'ci_theme').'</li>';

		if(empty($email) or !is_email($email))
			$errorString .= '<li>'.__('A valid email is required.', 'ci_theme').'</li>';

		if(empty($app_date) or strlen($app_date) != 10)
			$errorString .= '<li>'.__('A complete date is required', 'ci_theme').'</li>';

		if(!checkdate(substr($app_date, 5, 2), substr($app_date, 8, 2), substr($app_date, 0, 4)))
			$errorString .= '<li>'.__('The date must be in the form yyyy/mm/dd', 'ci_theme').'</li>';

		if(empty($service_id) or !is_numeric($service_id) or $service_id < 1)
		{
			$errorString .= '<li>'.__('You must select the service you are interested in', 'ci_theme').'</li>';
		}
		else
		{
			$service = get_post($service_id);
			if($service===null or get_post_type($service)!='service')
			{
				// Someone tried to pass a post id that isn't a service. Kinky.
				$errorString .= '<li>'.__('You must select the service you are interested in', 'ci_theme').'</li>';
			}
		}
		
		// Message is optional, so, no check.


		// Alright, lets send the email already!
		if(empty($errorString))
		{
			$mailbody  = __("Name:", 'ci_theme') . " " . $clientname . "\n";
			$mailbody .= __("Email:", 'ci_theme') . " " . $email . "\n";
			$mailbody .= __("Date:", 'ci_theme') . " " . $app_date . "\n";
			$mailbody .= __("Service:", 'ci_theme') . " " . $service->post_title . "\n";
			$mailbody .= __("Message:", 'ci_theme') . " " . $message . "\n";

			// If you want to receive the email using the address of the sender, comment the next $emailSent = ... line
			// and uncomment the one after it.
			// Keep in mind the following comment from the wp_mail() function source:
				/* If we don't have an email from the input headers default to wordpress@$sitename
				* Some hosts will block outgoing mail from this address if it doesn't exist but
				* there's no easy alternative. Defaulting to admin_email might appear to be another
				* option but some hosts may refuse to relay mail from an unknown domain. See
				* http://trac.wordpress.org/ticket/5007.
				*/			
			$emailSent = wp_mail(ci_setting('appointment_form_email'), get_bloginfo('name').' - '. __('Appointment form', 'ci_theme'), $mailbody);
			//$emailSent = wp_mail(ci_setting('contact_form_email'), get_bloginfo('name').' - '. __('Appointment form', 'ci_theme'), $mailbody, 'From: "'.$clientname.'" <'.$email.'>');
		}
		
	}
?>

<?php get_header(); ?>

<main id="main" class="row">

	<?php if ( ci_setting('disable_map') == '' ) : ?>
		<div class="twelve columns map">
			<div class="wrap">
				<div id="map"></div>
			</div>
		</div>
	<?php endif; ?>

	<div class="eight columns">

		<?php while ( have_posts() ) : the_post(); ?>
			<article id="post-<?php the_ID(); ?>" <?php post_class('entry'); ?>>
				<div class="wrap">

					<?php if ( ci_has_image_to_show() ) : ?>
						<figure class="entry-thumb">
							<a data-rel="prettyPhoto" href="<?php echo ci_get_featured_image_src('full'); ?>">
								<?php ci_the_post_thumbnail(); ?>
							</a>
						</figure>
					<?php endif; ?>
	
					<div class="entry-content contact-content">

						<?php if(!empty($errorString)): ?>
							<div class="wrap">
							<ul id="formerrors">
								<?php echo $errorString; ?>
							</ul>
							</div>
						<?php endif; ?>
			
						<?php if($emailSent===true): ?>
							<div class="wrap">
							<p id="formsuccess"><?php _e('Your appointment request has been sent. We will contact you as soon as possible.', 'ci_theme'); ?></p>
							</div>
						<?php elseif($emailSent===false and isset($_POST['send_appointment']) and $errorString==''): ?>
							<div class="wrap">
							<p id="sendfail"><?php _e('There was a problem while sending the email. Please try again later.', 'ci_theme'); ?></p>
							</div>
						<?php endif; ?>

						<?php the_content(); ?>


						<?php if(  !isset($_POST['send_appointment'])  or  (isset($_POST['send_appointment']) and !empty($errorString))  ): ?>
							<form action="<?php the_permalink(); ?>" method="post" class="appointment-form">
								<p>
									<label for="the_name"><?php _e('Your name (required)', 'ci_theme'); ?></label>
									<input type="text" name="the_name" id="the_name" value="<?php echo esc_attr($clientname); ?>">
								</p>
		
								<p>
									<label for="the_email"><?php _e('Your email (required)', 'ci_theme'); ?></label>
									<input type="text" name="the_email" id="the_email" value="<?php echo esc_attr($email); ?>">
								</p>
		
								<p>
									<label for="app_date"><?php _e('Desired date', 'ci_theme'); ?></label>
									<input type="text" name="app_date" id="app_date" class="datepicker" value="<?php echo esc_attr($app_date); ?>">
								</p>
		
								<div class="service-select">
									<p>
										<label for="service_select"><?php _e('Service', 'ci_theme'); ?></label>
										<?php 
											wp_dropdown_posts(array(
												'id' => 'service_select',
												'post_type' => 'service',
												'selected' => $service_id,
												'show_option_none' => '&nbsp;'
											), 'service_select'); 
										?>
									</p>
								</div>
								
		
								<p>
									<label for="the_message"><?php _e('Message (e.g. special instructions, convenient timeframe, etc)', 'ci_theme'); ?></label>
									<textarea name="the_message" id="the_message" cols="30" rows="10"><?php echo esc_textarea($message); ?></textarea>
								</p>
		
								<p>
									<input type="submit" class="btn" name="send_appointment" id="send_appointment" value="<?php echo esc_attr(_x('Send', 'send form button', 'ci_theme')); ?>">
								</p>
							</form>  
						<?php endif; ?>


					</div>

				</div>
			</article>
		
		<?php endwhile; ?>

	</div>

	<?php get_sidebar(); ?>
</main>

<?php get_footer(); ?>
