<?php
/*
Template Name: Services Listing
*/
?>
<?php get_header(); ?>

<?php 
	global $post;
	$paged = get_query_var('paged') ? get_query_var('paged') : 1;
	$base_category = get_post_meta($post->ID, 'base_services_category', true);
	
	$args = array(
		'post_type' => 'service',
		'paged' => $paged,
	);
	
	$args_tax = array(
		'tax_query' => array(
			array(
				'taxonomy' => 'service-category',
				'field' => 'id',
				'terms' => $base_category,
				'include_children' => true
			)
		)
	);

	if(empty($base_category) or $base_category < 1)
		$services = new WP_Query($args);
	else
		$services = new WP_Query(array_merge($args, $args_tax));
?>


<main id="main" class="row">
	<?php
		$fullwidth = (get_post_meta($post->ID, 'services_fullwidth', true) == 'fullwidth' ? true : false);
		$cols = 'eight';

		if( $fullwidth )
			$cols = 'twelve';
	?>
	<div class="<?php echo $cols; ?> columns">
		<?php if ( $services->have_posts() ) : while ( $services->have_posts() ) : $services->the_post(); ?>
	
		<article id="post-<?php the_ID(); ?>" <?php post_class('entry'); ?>>
			<div class="wrap">
				<div class="row">
	
					<?php if ( has_post_thumbnail() ) : ?>
						<div class="six columns">
							<figure class="entry-thumb">
								<a title="<?php echo esc_attr(sprintf( __('Permanent Link to: %s', 'ci_theme'), get_the_title() )); ?>" href="<?php the_permalink(); ?>">
									<?php the_post_thumbnail('ci_thumb'); ?>
								</a>
							</figure>
						</div>
					<?php endif; ?>
	
					<?php if ( has_post_thumbnail() ) : ?>
						<div class="six columns entry-content">
					<?php else : ?>
						<div class="twelve columns entry-content">
					<?php endif; ?>

						<div class="entry-meta">
							<h1 class="entry-title"><a title="<?php echo esc_attr(sprintf( __('Permanent Link to: %s', 'ci_theme'), get_the_title() )); ?>" href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h1>
	
							<ul class="entry-details group">
								<?php
									$duration = get_post_meta($post->ID, 'ci_cpt_service_duration', true);
									$cost = get_post_meta($post->ID, 'ci_cpt_service_cost', true);
									$offer = get_post_meta($post->ID, 'ci_cpt_service_offer', true);
								?>
								<?php if( !empty( $duration ) ): ?>
									<li><?php _e('Duration:', 'ci_theme'); ?> <span><?php echo $duration; ?></span></li>
								<?php endif; ?>
								<?php if( !empty( $cost ) ): ?>
									<li><?php _e('Cost:', 'ci_theme'); ?> <span><?php echo $cost; ?></span></li>
								<?php endif; ?>
							</ul>
		
						</div>
	
						<div class="entry-excerpt">
							<?php the_excerpt(); ?>
						</div>
	
						<?php if(ci_setting('service_listing_links_to')=='appointment' and absint(ci_setting('appointment_form_page')) > 0): ?>
							<a class="read-more btn" href="<?php echo add_query_arg('service_select', $post->ID, get_permalink(ci_setting('appointment_form_page'))); ?>"><?php _e('Make an appointment', 'ci_theme'); ?></a>
						<?php else: ?>
							<?php ci_read_more(); ?>
						<?php endif; ?>

					</div>
				</div>

				<?php if( $offer == 'enabled'): ?>
					<span class="offer-badge"><b><?php _e('Special Offer', 'ci_theme'); ?></b></span>
				<?php endif; ?>

			</div>
		</article>
	
		<?php endwhile; endif; ?>

		<?php ci_pagination(array(), $services); ?>

		<?php wp_reset_postdata(); ?>
	</div>
	
	<?php
		if( !$fullwidth )
			get_sidebar();
	?>
</main>

<?php get_footer(); ?>
